@@ -22,7 +22,7 @@ class MetasploitModule < Msf::Exploit::Local
         This module abuses the Capcom.sys kernel driver's function that allows for an
         arbitrary function to be executed in the kernel from user land. This function
         purposely disables SMEP prior to invoking a function given by the caller.
-        This has been tested on Windows 7 x64.
+        This has been tested on Windows 7, 8.1 and Windows 10 (x64).
       },
       'License'         => MSF_LICENSE,
       'Author'          => [
@@ -36,7 +36,7 @@ class MetasploitModule < Msf::Exploit::Local
           'EXITFUNC'    => 'thread',
         },
       'Targets'         => [
-          [ 'Windows x64 (<= 8)', { 'Arch' => ARCH_X86_64 } ]
+          [ 'Windows x64 (<= 10)', { 'Arch' => ARCH_X86_64 } ]
         ],
       'Payload'         => {
           'Space'       => 4096,
@@ -51,7 +51,7 @@ class MetasploitModule < Msf::Exploit::Local
   end
 
   def check
-    if sysinfo['OS'] !~ /windows (7|8)/i
+    if sysinfo['OS'] !~ /windows (7|8|10)/i
       return Exploit::CheckCode::Unknown
     end
 
